/* testhashmap.vala
 *
 * Copyright (C) 2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __TESTS_TESTARRAYLIST_H__
#define __TESTS_TESTARRAYLIST_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS



void test_arraylist_get (void);
void test_arraylist_set (void);
void test_arraylist_insert (void);
void test_arraylist_remove_at (void);
void test_arraylist_index_of (void);
void test_arraylist_add (void);
void test_arraylist_clear (void);
void test_arraylist_contains (void);
void test_arraylist_remove (void);
void test_arraylist_size (void);
void test_arraylist_iterator (void);
void _main (char** args, int args_length1);


G_END_DECLS

#endif
